@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 """A getter for ExPASy."""
 
 from datetime import datetime
@@ -12,15 +10,14 @@ __all__ = [
     "ExPASyGetter",
 ]
 
-URL = "ftp://ftp.expasy.org/databases/enzyme/enzuser.txt"
+URL = "https://ftp.expasy.org/databases/enzyme/enzuser.txt"
 
 
 class ExPASyGetter(Getter):
     """A getter for ExPASy."""
 
-    bioregistry_id = "eccode"
+    bioregistry_id = "ec"
     name = "ExPASy"
-    # date_version_fmt = "%d-%b-%Y"
     version_type = VersionType.date
 
     def get(self) -> str:
