@@ -1,10 +1,8 @@
-# -*- coding: utf-8 -*-
-
 """A getter for RxNorm."""
 
 from datetime import datetime
 
-from ..utils import Getter, VersionType, get_soup
+from ..utils import Getter, VersionType, find, get_soup
 
 __all__ = [
     "RxNormGetter",
@@ -24,7 +22,8 @@ class RxNormGetter(Getter):
     def get(self) -> datetime:
         """Get the latest RxNorm version number."""
         soup = get_soup(URL)
-        raw_version = soup.find("th", {"class": "current"}).contents[2].strip()
+        tag = find(soup, "th", {"class": "current"})
+        raw_version = tag.contents[2].text.strip()
         raw_fmt = "%B %d, %Y"
         return datetime.strptime(raw_version, raw_fmt)
 
